# Changelog

All notable changes to this project will be documented in this file. See [commit-and-tag-version](https://github.com/absolute-version/commit-and-tag-version) for commit guidelines.

## [1.2.1](https://github.com/WAS-Insurance/paypal_python_sdk/compare/v1.1.0...v1.2.1) (2025-05-11)


### Bug Fixes

* "from" is a python reserved keyword. So using alias for it ([e2d08f4](https://github.com/WAS-Insurance/paypal_python_sdk/commit/e2d08f487795f798c1d1521849b1c52ab303d223))

## [1.2.0](https://github.com/WAS-Insurance/paypal_python_sdk/compare/v1.1.0...v1.2.0) (2025-05-11)


### Features

* Added feature to PATCH orders ([59cab9d](https://github.com/WAS-Insurance/paypal_python_sdk/commit/59cab9dace5e9e5811ccf96283fca5069ccac983))


### Bug Fixes

* Fixed import directives ([56a7617](https://github.com/WAS-Insurance/paypal_python_sdk/commit/56a76173d026701313c84fc13ba3dcc60f555456))
* Renamed package to fix imports ([4d63929](https://github.com/WAS-Insurance/paypal_python_sdk/commit/4d639294afc324fdaaa09c318c642986e747705f))

## [1.1.1](https://github.com/WAS-Insurance/paypal_python_sdk/compare/v1.1.0...v1.1.1) (2025-05-10)


### Bug Fixes

* Renamed package to fix imports ([4d63929](https://github.com/WAS-Insurance/paypal_python_sdk/commit/4d639294afc324fdaaa09c318c642986e747705f))

## 1.1.0 (2025-05-10)


### Features

* Added short_message and improved type hinting of details in ApiError ([ae0a9da](https://github.com/WAS-Insurance/paypal_python_sdk/commit/ae0a9da8962ee72385006e30e6f690ee860de134))
* Bumped python version to 3.11 for improved typing suppport ([43d3634](https://github.com/WAS-Insurance/paypal_python_sdk/commit/43d3634ff0e00ce3b64c603203f58142e78c4b02))


### Bug Fixes

* Fixed import error where PayPalError was not imported ([4814c2f](https://github.com/WAS-Insurance/paypal_python_sdk/commit/4814c2f8d2e79c894b45b09f21bd64cc93caf2d4))
* Using StrEnum with updated python 3.11 version ([b510a64](https://github.com/WAS-Insurance/paypal_python_sdk/commit/b510a64f69fee7959e6caa1ee0fbac7f72e521c6))
